# T1021.002 - Remote Services: SMB/Windows Admin Shares
## Hunt Tags
**ID:** T1021.002

**Last Modified:** 23/10/2020

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](TODO)

## ATT&CK Tags
**Tactic:** Lateral Movement

**Technique:** Remote Services: SMB/Windows Admin Shares

## Technical description of the attack
This attack uses the Service Control Manager (SCM) to remotely create and start a service by [interacting with the SCM over RPC/TCP](https://docs.microsoft.com/en-us/windows/win32/services/services-and-rpc-tcp). 

The Windows APIs to interact with SCM are defined in [winsvc.h](https://docs.microsoft.com/en-us/windows/win32/api/winsvc/). This is in fact the same APIs that PsExec (and PAExec) use for opening remote shells and running remote commands. However, since this is a documented and well-known API, any (advanced) attacker can easily create software which use the same APIs but doesn't match the existing signatures. 

## Permission required to execute the technique
Local administrator on target machine
## Detection description
This detection is based on detecting incoming RPC/TCP on the SCM, followed by the start of a child process of services.exe. Remotely interacting with the SCM triggers the RPC/TCP traffic on services.exe, and the creation of the child-processes is a result of starting the service. 

The query might look intimidating given it's size. That's why we've commented the query per logic block to walk you through the details. 

## Utilized Data Source
| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceProcessEvents | MDE | Process monitoring |
| - | DeviceNetworkEvents | MDE | Process use of network |
| - | DeviceFileCertificateInfo | MDE | - |

## Hunt details
### KQL

**FP Rate:** *Low*

**Source:** *MDE*

**Description:** *See above*

**Query:**

```C#
//This rule is fairly complex, hence this documentation.
// The rule tries to detect network activity from services.exe followed by 
// the start of a new childprocess of services.exe (i.e. a service start).
// The rule tries to filter false positives as much as possible. 
// since the FileProfile info is currently super unreliable (unsure why), we have to work around it.
// 
// The following list of lolbins is used to include all results which have a high reputation, but are lolbins
let lolbins = dynamic(["At.exe", "Atbroker.exe", "Bash.exe", "Bitsadmin.exe", "CertReq.exe", "Certutil.exe", "Cmd.exe", "Cmdkey.exe", "Cmstp.exe", "Control.exe", "Csc.exe", "Cscript.exe", "Desktopimgdownldr.exe", "Dfsvc.exe", "Diantz.exe", "Diskshadow.exe", "Dnscmd.exe", "Esentutl.exe", "Eventvwr.exe", "Expand.exe", "Extexport.exe", "Extrac32.exe", "Findstr.exe", "Forfiles.exe", "Ftp.exe", "GfxDownloadWrapper.exe", "Gpscript.exe", "Hh.exe", "Ie4uinit.exe", "Ieexec.exe", "Ilasm.exe", "Infdefaultinstall.exe", "Installutil.exe", "Jsc.exe", "Makecab.exe", "Mavinject.exe", "Microsoft.Workflow.Compiler.exe", "Mmc.exe", "MpCmdRun.exe", "Msbuild.exe", "Msconfig.exe", "Msdt.exe", "Mshta.exe", "Msiexec.exe", "Netsh.exe", "Odbcconf.exe", "Pcalua.exe", "Pcwrun.exe", "Pktmon.exe", "Presentationhost.exe", "Print.exe", "Psr.exe", "Rasautou.exe", "Reg.exe", "Regasm.exe", "Regedit.exe", "Regini.exe", "Register-cimprovider.exe", "Regsvcs.exe", "Regsvr32.exe", "Replace.exe", "Rpcping.exe", "Rundll32.exe", "Runonce.exe", "Runscripthelper.exe", "Sc.exe", "Schtasks.exe", "Scriptrunner.exe", "SyncAppvPublishingServer.exe", "Ttdinject.exe", "Tttracer.exe", "vbc.exe", "Verclsid.exe", "Wab.exe", "Wmic.exe", "Wscript.exe", "Wsreset.exe", "Xwizard.exe", "AgentExecutor.exe", "Appvlp.exe", "Bginfo.exe", "Cdb.exe", "csi.exe", "Devtoolslauncher.exe", "dnx.exe", "Dotnet.exe", "Dxcap.exe", "Excel.exe", "Mftrace.exe", "Msdeploy.exe", "msxsl.exe", "ntdsutil.exe", "Powerpnt.exe", "rcsi.exe", "Sqldumper.exe", "Sqlps.exe", "SQLToolsPS.exe", "Squirrel.exe", "te.exe", "Tracker.exe", "Update.exe", "vsjitdebugger.exe", "Winword.exe", "Wsl.exe"]);
// First we want to get all the networkevents triggered by services.exe
let networkEvents = materialize(DeviceNetworkEvents
| where InitiatingProcessFileName in~ ("services.exe")
| where ActionType == "InboundConnectionAccepted"
| project-rename TimestampNetworkAct=Timestamp);
// Next we want to get the list of childprocesses created by services.exe 
let allServices = materialize ((
DeviceProcessEvents 
// this where  is for optimization puposes as filtering is way faster than joins
| where DeviceId in ((networkEvents | project DeviceId))
// svchost and sppsvc are created very often as childprocesses of 
| where InitiatingProcessFileName =~ "services.exe" 
| project TimestampChild=Timestamp, DeviceId, DeviceName, FileName, ProcessCommandLine, SHA1, 
InitiatingProcessFileName, InitiatingProcessCommandLine, InitiatingProcessSHA1, InitiatingProcessId, TimestampServicesExe=InitiatingProcessCreationTime));
// now we're going to join the process creations and network events 
// and filter out all the tables _after_ the join where the child process 
// of svchost is not created shortly after the network activity (0 and 10 seconds). 
let serviceNetworkEvents = materialize(
(networkEvents 
    | join kind=inner hint.strategy=shuffle allServices on DeviceId, InitiatingProcessId, InitiatingProcessFileName
) 
| where datetime_diff("Second", TimestampChild, TimestampNetworkAct) between (0 .. 10)
// only get the results where the network activity occured more than 1 minute after services.exe has started (i.e. system boot)
| where datetime_diff("Second", TimestampNetworkAct, TimestampServicesExe) > 60);
// next we want to check the reputation of all procssess
// since FileProfile is not properly working, we use the built-in
// DeviceFileCertificateInfo for the AntiJoin.
// the goal is to create a list of SHA1 hashes of the spawned processess 
// which have a low prevelance and are not in de DeviceFileCertificateInfo
let serviceNetworkEventsWithSHA1 = materialize(serviceNetworkEvents
| summarize count() by SHA1
| join kind=leftanti hint.strategy=broadcast DeviceFileCertificateInfo on SHA1
| where count_ < 100);
//| invoke FileProfile(SHA1, 200));
// Finally, we need to bring everything together
// we take our subset of the childprocessess created by services.exe (serviceNetworkEvents)
// everything which is on our blacklist of SHA1 processess OR are lolbins, are filtered out
// and we filter out msiexec since that appears to come very often
serviceNetworkEvents
| where SHA1 in ((serviceNetworkEventsWithSHA1 | project SHA1)) or FileName in~ (lolbins) 
| where ProcessCommandLine !~ "msiexec.exe /V" 
//This summarize is optional if you want to group similar stuff.
//| summarize ActionType=make_set(ActionType), RemoteIPs=make_set(strcat(RemoteIP, ":", RemotePort, " (", RemoteUrl, ")")), LocalPort=make_set(LocalPort) by bin(TimestampNetworkAct, 1m), DeviceId, DeviceName, LocalIP, Protocol, AdditionalFields, bin(TimestampChild, 1m), FileName, ProcessCommandLine, SHA1, InitiatingProcessFileName, InitiatingProcessCommandLine1, bin(TimestampServicesExe, 1m) 
```

## Considerations
* The timing used to correlate incoming network traffic and child process execution is in a way arbitrary. I currently allow a slack of 10 second. If you get a lot of false positives due to the timing difference, you can most likely decrease this slack as in all my test-cases, the time between a network connection and a child service being spawned is less than 1 second. I just left it to 10 seconds as it doesn't add noise and can account for slower execution due to high CPU loads / slow networks. 
* The query ignores everything which happens in the first 60 seconds after the start of services.exe (i.e. system boot), you can consider to increase or decrease this value to tune your sensitivity curve.
* "msiexec.exe /V" is explicitly whitelisted because of the insane amount of occurences of this specific commandline. I'm not sure why it's there and what is does. Most documention I found online (incorrectly) refer to the /l**v** which is different from /v. It is a valid switch though, based on the error it shows when you run it. Please reach out (0xffhh on Twitter) if you know what it does, so I can update this documentation accordingly. 
* You might want to whitelist binaries in your environment which are known good to reduce the noise. Watch out for LOLBINs though.
* Improve the filtering to use FileInfo instead of the DeviceFileCertificate table. During my testing, this function seemed temporary broken in MDE. 

## False Positives
*  msiexec.exe /v
  

## Detection Blind Spots
* Don't start the service right after creation. Create it and wait for (or force) a reboot.
* Start the process >10 seconds after the initial connection. You need to ensure though, that the TCP connections is not terminated. The "time" between network traffic and child process start is measures from the start of the network connection. Not from the last network activity.
* Perform the lateral movement in the first 60 seconds after the start of the services.exe. 

## References
*  https://www.ired.team/offensive-security/lateral-movement/lateral-movement-abusing-service-configuration-manager