# T1021.003 - Remote Services: Distributed Component Object Model
## Hunt Tags
**ID:** T1021.003

**Last Modified:** 23/10/2020

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](TODO)

## ATT&CK Tags
**Tactic:** Lateral Movement

**Technique:** Remote Services: Distributed Component Object Model

## Technical description of the attack
The attack uses DCOM for lateral movement. This attack is described in lots of depth by blog posts of [CyberReason](https://www.cybereason.com/blog/dcom-lateral-movement-techniques) and more recently by [MDSec](https://www.mdsec.co.uk/2020/09/i-like-to-move-it-windows-lateral-movement-part-2-dcom/). Creating this rule was mostly inspired by the recent MDSec blog post. 

## Permission required to execute the technique
Local administrator on target machine
## Detection description
This detection works by detecting close time proximity between incoming network traffic on [RPC/TCP]((https://docs.microsoft.com/en-us/windows/win32/services/services-and-rpc-tcp)) followed by creation of a DCOM object, followed by a creation of the child process of the DCOM object. 

The query first identifies incoming network traffic over RPC/TCP followed by the creation of a DCOM object (process) within 2 seconds, followed by the creation of a child process of this DCOM object. 

## Utilized Data Source
| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceProcessEvents | MDE | Process monitoring |
| - | DeviceNetworkEvents | MDE | Process use of network |

## Hunt details
### KQL

**FP Rate:** *High*

**Source:** *MDE*

**Description:** *See above*

**Query:**

```C#
let rpcNetwEvents = materialize(DeviceNetworkEvents
| where InitiatingProcessFileName =~ "svchost.exe" and InitiatingProcessCommandLine contains "rpcss" and LocalPort == 135
| where LocalIP !~ RemoteIP and ActionType != "ListeningConnectionCreated"
| project TimestampNetwEvent=bin(Timestamp, 5s),TimestampNetwEventExact=Timestamp, DeviceId, DeviceName, RPCHostID=InitiatingProcessId, RPCHostFileName=InitiatingProcessFileName, LocalIP, RemoteIP);
let dcomProcEvents = materialize (DeviceProcessEvents
| where InitiatingProcessFileName =~ "svchost.exe" and InitiatingProcessCommandLine contains "dcomlaunch"
| project TimestampProcEvent=bin(Timestamp, 5s),TimestampProcEventExact=Timestamp, DeviceId, DeviceName, DCOMHostPID=InitiatingProcessId, DCOMHostFileName=InitiatingProcessFileName, DCOMPID=ProcessId, DCOMFileName=FileName, DCOMCmdLine=ProcessCommandLine);
let lastBootTime = materialize(DeviceProcessEvents
| where FileName =~ "services.exe"
| summarize LastBootTime=max(Timestamp) by DeviceId);
let RemoteDcomProcs = materialize(rpcNetwEvents
| join kind=inner dcomProcEvents on DeviceId 
| join kind=leftouter lastBootTime on DeviceId
| where TimestampProcEvent > LastBootTime+5m //Ignore first 5 min after boot
//avoiding < 2 since if the time between netw and proc creation is negative, they can't be related. Network event must come first. 
| where datetime_diff("second", TimestampProcEventExact, TimestampNetwEventExact) between (0 .. 2) 
//whitelisting some usual suspects which create lot of noise. This is dangerous though...huge gap for bypass. 
| where DCOMFileName  !in ("TiWorker.exe", "dllhost.exe", "backgroundTaskHost.exe", "mobsync.exe", "WmiPrvSE.exe", 
    "RuntimeBroker.exe", "smartscreen.exe", "SppExtComObj.Exe", "usocoreworker.exe", "browser_broker.exe", "ssoncom.exe"));
RemoteDcomProcs
| join kind=inner hint.strategy=broadcast (
    DeviceProcessEvents 
    | where InitiatingProcessParentFileName =~ "svchost.exe" and InitiatingProcessFileName in ((RemoteDcomProcs | project DCOMFileName))) 
on $left.DCOMHostPID == $right.InitiatingProcessParentId, DeviceId, $left.DCOMPID == $right.InitiatingProcessId
| where InitiatingProcessParentFileName =~ "svchost.exe" and InitiatingProcessFileName =~ DCOMFileName 
| where FileName !in~ ("csc.exe") //whitelisting the black magic of Defender.
| summarize make_set(ProcessCommandLine) by TimestampNetwEventExact, TimestampProcEventExact, DeviceId, DeviceName, InitiatingProcessId, LocalIP, RemoteIP, LastBootTime, DCOMCmdLine
```

## Considerations
* Whitelisting dllhost.exe and wmiprvse.exe is kind of dangerous. This is the lazy aproach. In a production environment, you should whitelist specific COM object for dllhost after "vetting" them. 
* There are a number of where clauses which might **seem** to be superfluous as they're already covered by a join. These are there for performance. Joins are extremely slow on very large tables. By decreasing the cardinality of the table with a filter prior to the join the query becomes way faster (and actually within execution time limits). It's a bit of a balancing game between CPU and Memory as too much filtering seems to trigger another limit which kills the query. Probably memory related. 
* The timing used to correlate incoming network traffic and DCOM process creation is in a way arbitrary. I currently allow a slack of 2 seconds. 
* The query ignores everything which happens in the first 5 minutesafter the start of services.exe (i.e. system boot), you can consider to increase or decrease this value to tune your sensitivity curve.
* "csc.exe" is explicitly whitelisted due to the noise of defender triggering csc.exe on a .cmdfile [as detailed here](https://posts.specterops.io/documenting-and-attacking-a-windows-defender-application-control-feature-the-hard-way-a-case-73dd1e11be3a). There are better ways of whitelisting this specific behavior. 
* You might want to remove items from the whitelist and see how it impacts your results. 

## False Positives
*  Too much to mention - the query in this form is only useful as hunt, not as detection rule. 
  

## Detection Blind Spots
* COM objects spawned with dllhost.exe. 
* PPID spoofing when running your code to migrate out of the DCOM object to break the relation between the DCOM object and the child process. 
* Perform the lateral movement in the first 5 minutes after the start of the services.exe. 

## References
*  https://www.ired.team/offensive-security/lateral-movement/t1175-distributed-component-object-model
*  https://www.mdsec.co.uk/2020/09/i-like-to-move-it-windows-lateral-movement-part-2-dcom/
*  https://posts.specterops.io/documenting-and-attacking-a-windows-defender-application-control-feature-the-hard-way-a-case-73dd1e11be3a